@@ -163,12 +163,7 @@ Always display this group, even when there are no unread articles
 in it..")
 
     (charset (string :tag "Charset") "\
-The default charset to use in the group.") 
-
-    (iso-8859-1-forced (const :tag "Force ISO 8859-1 to default charset" 
-			      t)"\
-Force ISO 8859-1 to default charset in the group.") 
-)
+The default charset to use in the group."))
   "Alist of valid group parameters.
 
 Each entry has the form (NAME TYPE DOC), where NAME is the parameter
